---
name: Bug report
about: Create a report to help us improve
title: ''
labels: 'bug'
assignees: ''

---

Please, make sure you are using the last version of Cloup before
opening a bug report.

#### Bug description
A clear and concise description of what the bug is.

#### To Reproduce
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

#### Expected behavior
Delete this section if the expected behavior is obvious.

#### Screenshots
If applicable, add screenshots to help explain your problem.
